@@ -1,5 +1,5 @@
 /* Low level DECstation interface to ptrace, for GDB when running native.
-   Copyright 1988, 1989, 1991, 1992 Free Software Foundation, Inc.
+   Copyright 1988, 1989, 1991, 1992, 1995 Free Software Foundation, Inc.
    Contributed by Alessandro Forin(af@cs.cmu.edu) at CMU
    and by Per Bothner(bothner@cs.wisc.edu) at U.Wisconsin.
 
@@ -17,7 +17,7 @@ GNU General Public License for more details.
 
 You should have received a copy of the GNU General Public License
 along with this program; if not, write to the Free Software
-Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.  */
+Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.  */
 
 #include "defs.h"
 #include "inferior.h"
@@ -101,11 +101,13 @@ store_inferior_registers (regno)
   register unsigned int regaddr;
   char buf[80];
 
-  if (regno == 0)
-    return;
-
   if (regno > 0)
     {
+      if (regno == ZERO_REGNUM || regno == PS_REGNUM
+	  || regno == BADVADDR_REGNUM || regno == CAUSE_REGNUM
+	  || regno == FCRIR_REGNUM || regno == FP_REGNUM
+	  || (regno >= FIRST_EMBED_REGNUM && regno <= LAST_EMBED_REGNUM))
+	return;
       regaddr = REGISTER_PTRACE_ADDR (regno);
       errno = 0;
       ptrace (PT_WRITE_U, inferior_pid, (PTRACE_ARG3_TYPE) regaddr,
@@ -119,22 +121,7 @@ store_inferior_registers (regno)
   else
     {
       for (regno = 0; regno < NUM_REGS; regno++)
-	{
-	  if (regno == ZERO_REGNUM || regno == PS_REGNUM
-	      || regno == BADVADDR_REGNUM || regno == CAUSE_REGNUM
-	      || regno == FCRIR_REGNUM || regno == FP_REGNUM
-	      || (regno >= FIRST_EMBED_REGNUM && regno <= LAST_EMBED_REGNUM))
-	    continue;
-	  regaddr = REGISTER_PTRACE_ADDR (regno);
-	  errno = 0;
-	  ptrace (6, inferior_pid, (PTRACE_ARG3_TYPE) regaddr,
-		  read_register (regno));
-	  if (errno != 0)
-	    {
-	      sprintf (buf, "writing all regs, number %d", regno);
-	      perror_with_name (buf);
-	    }
-	}
+	store_inferior_registers (regno);
     }
 }
 
@@ -149,14 +136,15 @@ get_longjmp_target(pc)
      CORE_ADDR *pc;
 {
   CORE_ADDR jb_addr;
+  char buf[TARGET_PTR_BIT / TARGET_CHAR_BIT];
 
-  jb_addr = read_register(A0_REGNUM);
+  jb_addr = read_register (A0_REGNUM);
 
-  if (target_read_memory(jb_addr + JB_PC * JB_ELEMENT_SIZE, pc,
-			 sizeof(CORE_ADDR)))
+  if (target_read_memory (jb_addr + JB_PC * JB_ELEMENT_SIZE, buf,
+			  TARGET_PTR_BIT / TARGET_CHAR_BIT))
     return 0;
 
-  SWAP_TARGET_AND_HOST(pc, sizeof(CORE_ADDR));
+  *pc = extract_address (buf, TARGET_PTR_BIT / TARGET_CHAR_BIT);
 
   return 1;
 }
@@ -174,7 +162,7 @@ get_longjmp_target(pc)
 	    Original upage address X is at location core_reg_sect+x+reg_addr.
  */
 
-void
+static void
 fetch_core_registers (core_reg_sect, core_reg_size, which, reg_addr)
      char *core_reg_sect;
      unsigned core_reg_size;
@@ -193,7 +181,11 @@ fetch_core_registers (core_reg_sect, core_reg_size, which, reg_addr)
      core file without a upage, reg_ptr will be zero and this is all a big
      NOP.  */
   if (reg_ptr > core_reg_size)
+#ifdef KERNEL_U_ADDR
     reg_ptr -= KERNEL_U_ADDR;
+#else
+    error ("Old mips core file can't be processed on this machine.");
+#endif
 
   for (regno = 0; regno < NUM_REGS; regno++)
     {
@@ -231,3 +223,20 @@ register_addr (regno, blockend)
 
   return addr;
 }
+
+
+/* Register that we are able to handle mips core file formats.
+   FIXME: is this really bfd_target_unknown_flavour? */
+
+static struct core_fns mips_core_fns =
+{
+  bfd_target_unknown_flavour,
+  fetch_core_registers,
+  NULL
+};
+
+void
+_initialize_core_mips ()
+{
+  add_core_fns (&mips_core_fns);
+}
