@@ -12,7 +12,7 @@
 
    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
-   Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.  */
+   Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.  */
 
 /* This started out life as code shared between the nindy monitor and
    GDB.  For various reasons, this is no longer true.  Eventually, it
@@ -55,6 +55,11 @@
 #include <stdio.h>
 #include "defs.h"
 #include "serial.h"
+#ifdef ANSI_PROTOTYPES
+#include <stdarg.h>
+#else
+#include <varargs.h>
+#endif
 
 #if !defined (HAVE_TERMIOS) && !defined (HAVE_TERMIO) && !defined (HAVE_SGTTY)
 #define HAVE_SGTTY
@@ -101,16 +106,32 @@ static ninStrGet();
  *	format string) and that outputs nothing if verbose output has been
  *	suppressed.
  *****************************************************************************/
-/* FIXME: use varargs for this.  */
-static
-say( fmt, arg1, arg2 )
-    char *fmt;
-    int arg1, arg2;
+
+/* VARARGS */
+static void
+#ifdef ANSI_PROTOTYPES
+say (char *fmt, ...)
+#else
+say (va_alist)
+     va_dcl
+#endif
 {
-	if ( !quiet ){
-		printf( fmt, arg1, arg2 );
-		fflush( stdout );
-	}
+  va_list args;
+#ifdef ANSI_PROTOTYPES
+  va_start(args, fmt);
+#else
+  char *fmt;
+
+  va_start (args);
+  fmt = va_arg (args, char *);
+#endif
+
+  if (!quiet)
+    {
+      vfprintf_unfiltered (gdb_stdout, fmt, args);
+      gdb_flush (gdb_stdout);
+    }
+  va_end (args);
 }
 
 /******************************************************************************
@@ -628,7 +649,7 @@ ninBptDel( addr, type )
 	if ( addr == -1 ){
 		send( buf, 2, NULL );
 	} else {
-		store_unsigned_integer (&buf[2], addr, 4);
+		store_unsigned_integer (&buf[2], 4, addr);
 		send( buf, 6, NULL );
 	}
 }
@@ -653,7 +674,7 @@ ninBptSet( addr, type )
 
 	buf[0] = 'B';
 	buf[1] = type;
-	store_unsigned_integer (&buf[2], addr, 4);
+	store_unsigned_integer (&buf[2], 4, addr);
 	send( buf, 6, NULL );
 }
 
@@ -782,7 +803,7 @@ ninMemGet(ninaddr, hostaddr, len)
 		cnt = len > BUFSIZE ? BUFSIZE : len;
 
 		buf[0] = 'm';
-		store_unsigned_integer (&buf[1], ninaddr, 4);
+		store_unsigned_integer (&buf[1], 4, ninaddr);
 		buf[5] = cnt & 0xff;
 		buf[6] = (cnt>>8) & 0xff;
 
@@ -814,7 +835,7 @@ ninMemPut( ninaddr, hostaddr, len )
 		cnt = len > BUFSIZE ? BUFSIZE : len;
 
 		buf[0] = 'M';
-		store_unsigned_integer (&buf[1], ninaddr, 4);
+		store_unsigned_integer (&buf[1], 4, ninaddr);
 		memcpy(buf + 5, hostaddr, cnt);
 		send( buf, cnt+5, NULL );
 
@@ -874,7 +895,7 @@ ninRegPut( regname, val )
 
 	sprintf( buf, "U%s:", regname );
 	len = strlen(buf);
-	store_unsigned_integer (&buf[len], val, 4);
+	store_unsigned_integer (&buf[len], 4, val);
 	send( buf, len+4, NULL );
 }
 
@@ -1041,7 +1062,7 @@ ninSrq()
 	/* Send request termination status to NINDY
 	 */
 	buf[0] = 'e';
-	store_unsigned_integer (&buf[1], retcode, 4);
+	store_unsigned_integer (&buf[1], 4, retcode);
 	send( buf, 5, NULL );
 }
 
@@ -1097,7 +1118,7 @@ ninStrGet( ninaddr, hostaddr )
 	unsigned char cmd[5];
 
 	cmd[0] = '"';
-	store_unsigned_integer (&cmd[1], ninaddr, 4);
+	store_unsigned_integer (&cmd[1], 4, ninaddr);
 	send( cmd, 5, hostaddr );
 }
 
